Other Python Game theory libraries
==================================

- `Axelrod <http://axelrod.readthedocs.io/en/stable/>`_: a research library
  aimed at the study of the Iterated Prisoners dilemma [Knight2016]_.
- `Gambit <http://www.gambit-project.org/>`_: a C library with a Python
  interface for the computation of equilibria [McKelvey2016]_.
  :ref:`relation-to-gambit`.
- `Game theory explorer <http://gte.csc.liv.ac.uk/ndex/>`_ a web interface to
  gambit useful for teaching. [Savani2015]_
- `PyNFG <https://pypi.python.org/pypi/PyNFG/0.1.2/>`_: PyNFG is a Python
  package for modeling and solving Network Form Games.
- `lrslib <http://cgm.cs.mcgill.ca/~avis/C/lrs.html>`_: A C implementation of a
  reverse search algorithm with modules for Nash equilibria computation.
- `sagemath
  <http://doc.sagemath.org/html/en/reference/game_theory/index.html>`_: The
  mathematical software package Sage has various algorithms for the computation
  of Nash equilibria.
